fsaverage5


Notes
-----
Fsaverage5 standard spheres as distributed with Freesurfer (Fischl et al, 1999)

Content
-------
    :'sphere_left': Gifti file, left hemisphere spherical surface mesh
    :'sphere_right': Gifti file, right hemisphere spherical surface mesh

References
----------
Fischl et al, (1999). High-resolution intersubject averaging and a
coordinate system for the cortical surface. Hum Brain Mapp 8, 272-284.
